function [coeffs_adjusted,deleted] = adjust_coeffs(coeffs,count)
%ADJUST_COEFFS apply statistical adjustment to Fourier coefficients
%   [coeffs_adjusted,deleted] = ADJUST_COEFFS(coeffs,count) performs
%   statistical adjustments on Fourier coefficients generated from spike
%   trains, for use in the Fourier information estimation. A primary
%   assumption of the method is time-stationarity of the input spike
%   trains. Sometimes deviations result in different trials having somewhat
%   different statistical properties.
%
%   The adjustment performed here adjusts the magnitude of the coefficients
%   of each trial so as to bring them closer to the average trial.
%
%   An additional adjustment is the deletion of trials in which at least
%   one cell fires zero spikes; this prevents accurate adjustment and
%   fuddles the output.
%
%   Input:  coeffs              * MxTxD matrix of Fourier coefficients
%           count               * MxT matrix of spike counts for each trial
%   Output: coeffs_adjusted     * MxTxD matrix of adjusted coefficients
%           deleted             * 1xT logical vector of deleted trials
%
%   Written by Marshall Crumiller
%   email: mcrumiller@gmail.com
%--------------------------------------------------------------------------
% remove zero-spike trials
deleted=any(count==0,1); coeffs(:,deleted,:)=[];
count(:,deleted)=[];

[~,T,D]=size(coeffs);

% grab mean spike count
mean_spike_count=mean(count,2);

% scale each trial by the square root of the ratio of the per-trial spike
% count and the mean
scaling_factor = repmat(mean_spike_count,1,T)./count;
scaling_factor(isinf(scaling_factor))=0;
scaling_factor=repmat(scaling_factor,[1 1 D]);
coeffs_adjusted = coeffs.*sqrt(scaling_factor);