function [scores, freq] = spiketime2fourier(spikes, max_frequency, time)
%SPIKETIME2FOURIER   calculate Fourier coefficients of spike trains
% [scores, freq] = SPIKETIME2FOURIER(spikes, max_frequency, time) produces
% a Fourier Series for each spike train up to the provided maximum
% frequency.
%
% Usage: [scores, freq] = spiketime2fourier(spikes, max_frequency, time,...
%      smoothing_window);
%
% Input:  spikes                      * MxT cell array of spiketimes
%         max_frequency               * maximum basis frequency
%         time                        * trial length
% Output: scores                      * matrix of projected spiketimes
%         freq                        * 1xD vector of frequency values
%--------------------------------------------------------------------------
spikes = cell2mat_trials(spikes); % convert to zero-padded matrix

% When we apply a cosine to the zero-padded locations, we'll get a "1"
% regardless of frequency. We'll need to know how many 1's to subtract off
% at the end
zero_locs = ~(spikes~=0);
nospikes = single(sum(zero_locs,3));
dF=1/time;
freq=dF:dF:max_frequency+dF/4; % extra dF/4 in case of roundoff error

% calculate sin functions
mult = freq*2*pi;
D=length(freq);

% note that this actually doesn't use any more memory, since we're
% repmatting a cell matrix, which is just a list of pointers
m=num2cell(mult,1);
s=repmat({spikes},1,D);
s1=cell(1);

% generate complex coefficients
% note: the first two singleton dimensions allow cell2mat() to properly
% format the resulting matrix
s1(1,1,1:D)=cellfun(@(x,y) sum(cos(x*y),3)-nospikes+1i*sum(sin(x*y),3),s,m,'UniformOutput',false);
scores=cell2mat(s1);
scores(~isfinite(scores))=0;